summaryrefslogtreecommitdiffstats
path: root/libkdegames/kgame/dialogs/kgamedialogconfig.h
diff options
context:
space:
mode:
Diffstat (limited to 'libkdegames/kgame/dialogs/kgamedialogconfig.h')
-rw-r--r--libkdegames/kgame/dialogs/kgamedialogconfig.h32
1 files changed, 19 insertions, 13 deletions
diff --git a/libkdegames/kgame/dialogs/kgamedialogconfig.h b/libkdegames/kgame/dialogs/kgamedialogconfig.h
index 911c63aa..7c42d05d 100644
--- a/libkdegames/kgame/dialogs/kgamedialogconfig.h
+++ b/libkdegames/kgame/dialogs/kgamedialogconfig.h
@@ -48,11 +48,12 @@ class KGameDialogConfigPrivate;
* @short Base class for configuration widgets
* @author Andreas Beckermann <b_mann@gmx.de>
**/
-class KDE_EXPORT KGameDialogConfig : public QWidget
+class KDE_EXPORT KGameDialogConfig : public TQWidget
{
Q_OBJECT
+ TQ_OBJECT
public:
- KGameDialogConfig(TQWidget* parent = 0);
+ KGameDialogConfig(TQWidget* tqparent = 0);
virtual ~KGameDialogConfig();
/**
@@ -136,7 +137,7 @@ private:
* The main game configuration widget.
*
* It currently contains a line edit for the name of the player only. You can
* add widgets by using the KGameDialogGeneralConfig as parent parameter as it
* uses TQLayout::autoAdd == true.
* @author Andreas Beckermann <b_mann@gmx.de>
**/
@@ -144,23 +145,24 @@ class KGameDialogGeneralConfigPrivate;
class KGameDialogGeneralConfig : public KGameDialogConfig
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Construct a KGameDialogGeneralConfig. Currently it contains a line
* edit widget to change the player name only.
*
* If you just want to add more widgets you can just create your widgets
* with the KGameDialogGeneralConfig as parent as it uses
* TQLayout::setAutoAdd(true).
*
* @param parent Parent widget for this dialog.
* @param initializeGUI If you really don't want to use the
- * predefined widget and/or layout use FALSE here. Note that then none
+ * predefined widget and/or tqlayout use FALSE here. Note that then none
* of the predefined widgets (currently only the name of the player)
* will exist anymore.
*
**/
- KGameDialogGeneralConfig(TQWidget* parent = 0, bool initializeGUI = true);
+ KGameDialogGeneralConfig(TQWidget* tqparent = 0, bool initializeGUI = true);
virtual ~KGameDialogGeneralConfig();
/**
@@ -211,8 +213,9 @@ class KGameDialogNetworkConfigPrivate;
class KDE_EXPORT KGameDialogNetworkConfig : public KGameDialogConfig
{
Q_OBJECT
+ TQ_OBJECT
public:
- KGameDialogNetworkConfig(TQWidget* parent = 0);
+ KGameDialogNetworkConfig(TQWidget* tqparent = 0);
virtual ~KGameDialogNetworkConfig();
@@ -248,7 +251,7 @@ public:
* @param type Service type (something like _kwin4._tcp). It should be unique for application.
* @since 3.4
**/
- void setDiscoveryInfo(const TQString& type, const TQString& name=TQString::null);
+ void setDiscoveryInfo(const TQString& type, const TQString& name=TQString());
signals:
/**
@@ -277,8 +280,9 @@ class KGameDialogMsgServerConfigPrivate;
class KGameDialogMsgServerConfig : public KGameDialogConfig
{
Q_OBJECT
+ TQ_OBJECT
public:
- KGameDialogMsgServerConfig(TQWidget* parent = 0);
+ KGameDialogMsgServerConfig(TQWidget* tqparent = 0);
virtual ~KGameDialogMsgServerConfig();
virtual void submitToKGame(KGame*, KPlayer*) {}
@@ -294,7 +298,7 @@ protected slots:
void slotRemoveClient();
protected:
- void removeClient(Q_UINT32 id);
+ void removeClient(TQ_UINT32 id);
private:
KGameDialogMsgServerConfigPrivate* d;
@@ -310,8 +314,9 @@ class KGameDialogChatConfigPrivate;
class KGameDialogChatConfig : public KGameDialogConfig
{
Q_OBJECT
+ TQ_OBJECT
public:
- KGameDialogChatConfig(int chatMsgId, TQWidget* parent = 0);
+ KGameDialogChatConfig(int chatMsgId, TQWidget* tqparent = 0);
virtual ~KGameDialogChatConfig();
virtual void setKGame(KGame* g);
@@ -331,8 +336,9 @@ class KGameDialogConnectionConfigPrivate;
class KGameDialogConnectionConfig : public KGameDialogConfig
{
Q_OBJECT
+ TQ_OBJECT
public:
- KGameDialogConnectionConfig(TQWidget* parent = 0);
+ KGameDialogConnectionConfig(TQWidget* tqparent = 0);
virtual ~KGameDialogConnectionConfig();
virtual void setKGame(KGame* g);
@@ -136,7 +137,7 @@ private:
*
* It currently contains a line edit for the name of the player only. You can
- * add widgets by using the KGameDialogGeneralConfig as parent parameter as it
+ * add widgets by using the KGameDialogGeneralConfig as tqparent parameter as it
* uses TQLayout::autoAdd == true.
* @author Andreas Beckermann <b_mann@gmx.de>
@@ -144,23 +145,24 @@ class KGameDialogGeneralConfigPrivate;
*
* If you just want to add more widgets you can just create your widgets
- * with the KGameDialogGeneralConfig as parent as it uses
+ * with the KGameDialogGeneralConfig as tqparent as it uses
* TQLayout::setAutoAdd(true).
*
@@ -144,23 +145,24 @@ class KGameDialogGeneralConfigPrivate;
* TQLayout::setAutoAdd(true).
*
- * @param parent Parent widget for this dialog.
+ * @param tqparent Parent widget for this dialog.
* @param initializeGUI If you really don't want to use the